# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/tabela-sac',
                'doc_host': 'https://joaopcnogueira.github.io',
                'git_url': 'https://github.com/joaopcnogueira/tabela-sac',
                'lib_path': 'tabela_sac'},
  'syms': { 'tabela_sac.cli': { 'tabela_sac.cli.gerar_tabela_sac': ('cli.html#gerar_tabela_sac', 'tabela_sac/cli.py'),
                                'tabela_sac.cli.install_package': ('cli.html#install_package', 'tabela_sac/cli.py')},
            'tabela_sac.core': { 'tabela_sac.core.SACCalculator': ('core.html#saccalculator', 'tabela_sac/core.py'),
                                 'tabela_sac.core.SACCalculator.__init__': ('core.html#saccalculator.__init__', 'tabela_sac/core.py'),
                                 'tabela_sac.core.SACCalculator.amortizacao_extra_mensal': ( 'core.html#saccalculator.amortizacao_extra_mensal',
                                                                                             'tabela_sac/core.py'),
                                 'tabela_sac.core.SACCalculator.tabela': ('core.html#saccalculator.tabela', 'tabela_sac/core.py')}}}
